package org.ow2.util.ee.metadata.war.impl.configurator;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployable.WARDeployable;
import org.ow2.util.ee.metadata.war.impl.WarDeployableMetadata;
import org.ow2.util.ee.metadata.war.impl.specific.ISpecificWarDeployableMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IArchiveConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;

/**
 * EjbJarArchiveMetadataConfigurator.
 * @author Gael Lalire
 */
public class WarDeployableMetadataConfigurator implements IArchiveConfigurator {

    /**
     * specificWarDeployableMetadataConfiguratorList.
     */
    private List<ISpecificWarDeployableMetadataConfigurator>
        specificWarDeployableMetadataConfiguratorList;

    /**
     * archive metadata.
     */
    private WarDeployableMetadata warDeployableMetadata;

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * Constructor.
     * @param warDeployable the web archive
     */
    public WarDeployableMetadataConfigurator(final WARDeployable warDeployable) {
        this.warDeployableMetadata = new WarDeployableMetadata(warDeployable);
        annotationParsingDesactived = false;
        specificWarDeployableMetadataConfiguratorList =
            new ArrayList<ISpecificWarDeployableMetadataConfigurator>();
    }

    /**
     * @param jClass signature
     * @return class configurator
     */
    public IClassConfigurator createClassConfigurator(final JClass jClass) {
        return new WarClassMetadataConfigurator(jClass, this.warDeployableMetadata, annotationParsingDesactived,
                specificWarDeployableMetadataConfiguratorList);
    }

    /**
     * @return the archive metadata
     */
    public WarDeployableMetadata getWarDeployableMetadata() {
        return this.warDeployableMetadata;
    }

    /**
     * @return true if annotation parsing is desactived
     */
    public boolean isAnnotationParsingDesactived() {
        return this.annotationParsingDesactived;
    }

    /**
     * Set annotationParsingDesactived.
     * @param annotationParsingDesactived true if you want to desactive
     *        annotation parsing
     */
    public void setAnnotationParsingDesactived(final boolean annotationParsingDesactived) {
        this.annotationParsingDesactived = annotationParsingDesactived;
    }

    /**
     * Add a specific war deployable metadata configurator.
     * @param specificWarDeployableMetadataConfigurator the specific war
     *        deployable metadata configurator
     */
    public void addSpecificMetadataConfigurator(
            final ISpecificWarDeployableMetadataConfigurator specificWarDeployableMetadataConfigurator) {
        specificWarDeployableMetadataConfiguratorList.add(specificWarDeployableMetadataConfigurator);
    }

}
