/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WAREntityResolver.java 5741 2011-02-28 15:53:04Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.xml.parsing;


import org.ow2.util.ee.metadata.common.impl.xml.parsing.IEntityResolver;
import org.ow2.util.xml.SchemaEntityResolver;


/**
 * Entity resolver allowing to find schema within the classloader.
 *
 * @author Florent Benoit
 */
public class WAREntityResolver extends SchemaEntityResolver implements IEntityResolver {

    /**
     * All schemas used by WARs.
     */
    private static final String[] WAR_SCHEMAS = new String[]{PREFIX + JSP20_SCHEMA,
        PREFIX + JSP21_SCHEMA,
        PREFIX + JSP22_SCHEMA,

            PREFIX + WEBAPP24_SCHEMA,
            PREFIX + WEBAPP25_SCHEMA,
            PREFIX + WEBAPP30_SCHEMA,
            PREFIX + CLIENT50_SCHEMA,
            PREFIX + CLIENT60_SCHEMA,
            PREFIX + JAVAEE5_SCHEMA,
            PREFIX + JAVAEE6_SCHEMA,
            PREFIX + J2EE14_SCHEMA, PREFIX + JAVAEE_WEBSERVICES12_CLIENT_SCHEMA,
            PREFIX + JAVAEE_WEBSERVICES13_CLIENT_SCHEMA,
            PREFIX + J2EE_WEBSERVICES_CLIENT_SCHEMA,
            PREFIX + XML_SCHEMA};

    /**
     * All Public ID used by Clients.
     */
    private static final String[] WAR_PUBLIC_IDS = new String[] {
            XMLSCHEMA_PUBLIC_ID,
            DATATYPES_PUBLIC_ID,
            WEBAPP22_PUBLIC_ID,
            WEBAPP23_PUBLIC_ID
    };

    /**
     * All DTDs filename used by Clients.
     */
    private static final String[] WAR_DTDS = new String[] {
            PREFIX + XMLSCHEMA_DTD,
            PREFIX + DATATYPES_DTD,
            PREFIX + WEBAPP22_DTD,
            PREFIX + WEBAPP23_DTD
    };


    /**
     * Constructor. Finds the XSD with classloader.
     */
    public WAREntityResolver() {
        super(WAR_SCHEMAS, WAR_PUBLIC_IDS, WAR_DTDS);
    }

}
